package Src;
import java.io.* ;

/**
 *  Classe permettant de lire un fichier de stations.
 *
 *  Chaque ligne du fichier est de la forme :
 *  100475:ROUEN
 *  num???ro de sommet:Ville
 */

public class LecteurStations {

    private BufferedReader in ;
    private boolean open ;
    private String Filename ;
    private int linenb ;

    /** Contient le num???ro de sommet. */
    public int numeroSommet ;

    /** Contient le nom de la station. */
    public String nom ;


    /**
     * @param  Filename  Nom du fichier contenant les stations.
     */
    public LecteurStations (String Filename) throws FileNotFoundException{
	this.Filename = Filename ;
	this.in = new BufferedReader(new FileReader(Filename)) ;
	this.open = true ;
	this.linenb = 0 ;
    }



    /**
     * Lit la station suivante dans le fichier.
     * Le num???ro de sommet et le nom de la ville sont plac???s dans les attributs de l'objet.
     * Cette m???thode peut ???tre invoqu???e sans risque d'erreur m???me s'il ne reste plus de stations ??? lire.
     *
     * @return      true si une station a bien ???t??? lue.
     */

    public boolean stationSuivante () {
	if (this.open) {
	    try {
		String line = in.readLine () ;
		if (line == null) return false ;

		line = line.trim () ;
		linenb = linenb + 1 ;

		if ((line.length () == 0) || (this.is_comment (line)) ) { return this.stationSuivante () ; }

		String[] splits = line.split (":", 2) ;
		
		numeroSommet = this.get_int ("du numero de sommet", splits[0].trim ()) ;
		nom = splits[1].trim () ;
		
		return true ;
	    }
	    catch (IOException e) {
		open = false ;
		try { in.close () ; } catch (IOException ee) {}
		return false ;
	    }
	}
	else return false ;
    }

    /*
     * R??cup??re une valeur String qu'elle transforme en entier
     */
    private int get_int (String champ, String v) {
	try {return ((new Integer (v)).intValue ()) ;}
	catch (NumberFormatException e) {
	    System.err.println("Fichier " + Filename + ", ligne " + linenb + " : erreur de lecture " + champ) ;
	    return 0 ;
	}
    }

    /*
     * Pour enlever les commentaires
     */
    private boolean is_comment (String line) {
	return line.startsWith("//") ;
    }

//Ancienne fonction pour la lecture
//    public static void main(String[] args) throws FileNotFoundException {
//	LecteurStations lect = new LecteurStations ("./Src/europe.stations") ;
//	
//	while (lect.stationSuivante ()) {
//	    System.out.println ("Station " + lect.numeroSommet + " ??? " + lect.nom) ;
//	}
//    }
    
/*
 * Pour r??cup??rer la liste des stations, on affecte ensuite les sommets en fonction (afin 
 * de savoir si le sommet est une station)
 */
    public static void lireStation(String nomFic, petitGraphe petitgraph) throws FileNotFoundException {
    	LecteurStations lect = new LecteurStations (nomFic) ;
		while (lect.stationSuivante()) {
			//graph.getListeSommets().get(lect.numeroSommet).setStation();
			//graph.setStation(lect.numeroSommet);
			petitgraph.insererSommet(lect.numeroSommet);
	   /* System.out.println ("Sommet " + lect.numeroSommet + " (" + lect.longitude + ", " +
				lect.latitude + ", " + lect.altitude + ")  " + lect.nom) ;*/
		}
    }
    
    public static int nbStations(String nomFic) throws FileNotFoundException {
    	int nb = 0;
    	LecteurStations lect = new LecteurStations (nomFic) ;
		while (lect.stationSuivante()) {
			nb++;
		}
		return nb;
    }
    

}